@@ -3,7 +3,6 @@
 #
 import numpy as np
 import re
-# import elog
 import os
 import matplotlib.pyplot as plt
 from scipy import optimize
@@ -403,9 +402,11 @@ class HREELS:
         ''' Set vertical marker with text label. Note that self.figure() needs to be 
         called before use.'''
         trans = offset(self.ax, 0, 30)
-        plt.plot([x,x],[ymin,y], lw=1, c='black', ls='dashed')
+        # plt.plot([x,x],[ymin,y], lw=1, c='black', ls='dashed')
+        self.ax.plot([x,x],[ymin,y], lw=1, c='black', ls='dashed')
         x = round(x)
-        plt.text(x,y,'%4i' % x, rotation=90, 
+        # plt.text(x,y,'%4i' % x, rotation=90, 
+        self.ax.text(x,y,'%4i' % x, rotation=90, 
         verticalalignment='bottom', horizontalalignment='center', transform=trans)
         return
 
