@@ -15,7 +15,8 @@ hhPath = os.path.dirname(__file__)
 from libhreels.HREELS import HREELS, myPath
 from datetime import datetime  
 import argparse
-import expLogbook as lgb
+# import libhreels.expLogbook as lgb
+import libhreels.NoExpLogbook as lgb
 
 # fix HighRes Displays
 QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
@@ -239,11 +240,12 @@ class HREELS_Window(QtWidgets.QMainWindow):
         self.showComment =  self.ui.checkBoxComment.isChecked()
         # print('onCommentSet:', lgb.available, self.showComment, self.ui.listWidget.selectedItems()[0].text())
         if self.showComment:
-            if lgb.available:
+            if lgb.available:                
                 text = lgb.logbook.getShortMessage4File(self.d.fname)
                 ids = lgb.logbook.search({'file':self.d.fname})
-                _, attributes, _ = lgb.logbook.read(ids[0])
-                print(self.d.fname, ids[0],':\t\t', attributes['Date'],'\t',text)
+                if len(ids) > 0:
+                    _, attributes, _ = lgb.logbook.read(ids[0])
+                    print(self.d.fname, ids[0],': ', attributes['Date'],'\t',text[:-2])
             else:
                 text = self.comment if self.comment else ''
                 self.comment = None
@@ -439,24 +441,23 @@ def runViewer(datapath= None, remoteDir=None, startWithFile=None, comment=None):
 def myMain():
     parser = argparse.ArgumentParser()
     #################  Command line handling  ######################
-    def validDate(string):
-        date = datetime.strptime(string, "%Y-%m-%d")
-        return date
     def is_valid_file(string):
         if not os.path.exists(string):
             parser.error("The file %s does not exist!" % string)
             return False
         else:
             return string
-    # parser.add_argument("-s", "--start", help="Start date (2018-01-01)", default='2019-01-01', type=validDate)
-    parser.add_argument("-f", "--file", help="Start viewer with this datafile", type=is_valid_file)
-    # parser.add_argument("-f", "--file", help="Start viewer with this datafile")
+    parser.add_argument("file", nargs='?', help="Start viewer with this datafile", type=is_valid_file)
+    parser.add_argument("-f", "--file2", help="Start viewer with this datafile")
     parser.add_argument("-c", "--comment", default=None, help="Text comment")
     args = parser.parse_args()
 
     if args.file:
         fPath,fName = os.path.split(args.file)
         # print(">>> ", fPath, " <<< ", fName)
+    elif args.file2:
+        fPath,fName = os.path.split(args.file2)
+        # print(">>> ", fPath, " <<< ", fName)
     else:
         if os.name == 'nt':
             fPath = "D:\\Data\\Python\\HREELS\\expHREELS\\data"
